@@ -147,7 +147,8 @@ protected:
 	 * Set the content of the string variable to that of a
 	 * formatted printf style string.
 	 *
-	 * @param string to copy from.
+	 * @param size of string data to set.
+	 * @param format of string to write into object.
 	 */
 	const char *set(size_t size, const char *format, ...);
 #endif
@@ -240,14 +241,14 @@ public:
 	/**
 	 * Create a String from std::string.
 	 *
-	 * @param string to set with.
+	 * @param string from std::string to copy from.
 	 */
-	String(std::string str);
+	String(std::string string);
 
 	/**
 	 * Create a new string from a subset of another string.	
 	 *
-	 * @param str prior string.	
+	 * @param str reference of source string.	
 	 * @param offset offset to start of data in prior string.
 	 * @param len length of our substring.
 	 */
@@ -258,10 +259,9 @@ public:
 	 * Create a string from formatted text input.
 	 *
 	 * @param size to allocate for our new string.
-	 * @param snprintf format.
-	 * @param data to input.
+	 * @param format of data to input.
 	 */
-	String(size_t count, const char *fmt, ...);
+	String(size_t size, const char *format, ...);
 #else
         /**
          * Create a string of a known size, and optionally fill with
@@ -452,7 +452,7 @@ public:
 	/**
 	 * Chop n leading characters from a string.
 	 *
-	 * @param count to chop.
+	 * @param chars count to chop.
 	 */
 	inline void chop(size_t chars)
 		{erase(0, chars);};
@@ -460,7 +460,7 @@ public:
 	/**
 	 * Trim n trailing characters from a string.
 	 *
-	 * @param count to trim.
+	 * @param count number of bytes to trim.
 	 */
 	void trim(size_t count);
 
@@ -506,9 +506,9 @@ public:
          *
          * @param start starting offset to replace at.
          * @param len length of text to remove.
-         * @param s string to replace with.
+         * @param string reference to replace with.
          */
-	void replace(size_t start, size_t len, const String &s);
+	void replace(size_t start, size_t len, const String &string);
 
 	/**
 	 * A more convenient version of find for nth occurences, by
@@ -519,19 +519,19 @@ public:
 	 * @param offset offset to start at.
 	 * @param len length of text.
 	 */
-	inline size_t find(unsigned instance, const char *cp, size_t offset = 0, size_t len = 0) const
-		{return find(cp, offset, len, instance);};
+	inline size_t find(unsigned instance, const char *text, size_t offset = 0, size_t len = 0) const
+		{return find(text, offset, len, instance);};
 
         /**
          * A more convenient version of find for nth occurences, by
          * putting the instance first.
          *
          * @param instance nth instance to look for.
-         * @param s string to look for.
+         * @param string reference to look for.
          * @param offset offset to start at.
          */
-	inline size_t find(unsigned instance, const String &s, size_t offset = 0) const
-		{return find(s, offset, instance);};
+	inline size_t find(unsigned instance, const String &string, size_t offset = 0) const
+		{return find(string, offset, instance);};
 
 	/**
 	 * Return a new string that contains a specific substring of the
@@ -549,7 +549,7 @@ public:
 	 * find.  If out of range, a NULL string is returned.
 	 *
 	 * @return pointer to string data from our string,
-	 * @param idx index or offset to use.
+	 * @param ind index or offset to use.
 	 */
 	inline const char *(index)(size_t ind) const
 		{return getIndex(ind);};
@@ -644,7 +644,7 @@ public:
 	 * Append formatted text to the end of the current string.
 	 *
 	 * @param size size of text to append.
-	 * @param text to append.
+	 * @param format of data to append.
 	 */
 	void append(size_t size, const char *format, ...);
 #endif
@@ -752,11 +752,11 @@ public:
 	 * Print values directly into a string variable.
 	 *
 	 * @return character count.
-	 * @param string to use.
+	 * @param str object reference to use.
 	 * @param size of string required.
-	 * @param format of data
+	 * @param format of data.
 	 */
-	friend __EXPORT int strprintf(String &str, size_t size, const char *fmt, ...);
+	friend __EXPORT int strprintf(String &str, size_t size, const char *format, ...);
 #endif
 
         bool operator<(const String &str) const;
