@@ -335,7 +335,7 @@ namespace ost {
   * @author Alex Pavloff <alex@pavloff.net>
   * @short Threaded streamable unix domain socket with non-blocking constructor.
   */
- class UnixSession : public UnixStream, public Thread
+ class __EXPORT UnixSession : public Thread, public UnixStream
  {
  protected:
  	/**
@@ -358,15 +358,8 @@ namespace ost {
  	 * terminates without having to wait for a connection request
  	 * to complete.
  	 */
- 	CCXX_MEMBER(void) initial(void);
+ 	void initial(void);
 
- 	/**
- 	 * UnixSession derived objects can be freely created with "new"
- 	 * and safely terminate their "Run" method on their own by
- 	 * self-deleting when the thread terminates.
- 	 */
- 	CCXX_MEMBER(void) final(void)
- 		{delete this;};
  public:
  	/**
  	 * Create a Unix domain socket that will be connected to a local server
@@ -390,6 +383,11 @@ namespace ost {
  	 */
  	UnixSession(UnixSocket &server, int size = 512,
  		   int pri = 0, int stack = 0);
+
+	/**
+	 * Virtual destructor.
+	 */
+	virtual ~UnixSession();
  };
 
 #endif // ndef WIN32
