@@ -1461,6 +1461,16 @@ void MappedFile::update(caddr_t address, size_t len)
 #endif
 #endif // ndef WIN32
 
+#ifdef	WIN32
+#ifndef	SECS_BETWEEN_EPOCHS
+#define	SECS_BETWEEN_EPOCHS 11644473600
+#endif
+
+#ifndef	SECS_TO_100NS
+#define	SECS_TO_100NS	10000000
+#endif
+#endif
+
 time_t lastAccessed(const char *path)
 {
 #ifdef	WIN32
