@@ -530,7 +530,7 @@ retry:
 		while(NULL != (cp = strchr(cp, '\\')))
 			*cp = '/';
 
-		cp = cp + strlen(path) - 1;
+		cp = path + strlen(path) - 1;
 		if(*cp != '/')
 		{
 			*(++cp) = '/';
