@@ -44,7 +44,7 @@
 #define	CCXX_PACKING
 
 // Config option: uncomment this line if you want to use static linkage!
-//#define CCXX_NO_DLL
+//#define CCXX_STATIC
 
 // define automatically WIN32 for windows application compiled with Borland
 #ifndef WIN32
@@ -56,6 +56,7 @@
 #endif
 
 #pragma warning(disable: 4996)
+#pragma warning(disable: 4355)
 
 // check multithreading
 #if defined(__BORLANDC__) && !defined(__MT__)
@@ -67,7 +68,7 @@
 
 // check DLL compiling
 #ifdef _MSC_VER
-#ifndef CCXX_NO_DLL
+#ifndef CCXX_STATIC
 # ifndef _DLL
 #  error Please enable DLL linking (Project -> Settings -> C/C++ -> Code Generation -> Use Runtime Library)
 # endif
@@ -154,10 +155,6 @@ WIN32_LEAN_AND_MEAN
 #endif
 
 #undef	__DLLRTL
-#undef CCXX_EXPORT
-#undef CCXX_MEMBER
-#undef CCXX_MEMBER_EXPORT
-#undef CCXX_CLASS_EXPORT
 #undef CCXX_EMPTY
 #define CCXX_EMPTY
 
@@ -175,10 +172,6 @@ WIN32_LEAN_AND_MEAN
 #undef __stdcall
 #define __stdcall
 #define	__EXPORT
-#define CCXX_EXPORT(t) t
-#define CCXX_MEMBER(t) t
-#define CCXX_MEMBER_EXPORT(t) t
-#define CCXX_CLASS_EXPORT
 typedef char int8;
 typedef short int16;
 typedef long int32;
@@ -205,12 +198,14 @@ typedef DWORD size_t;
 
 #else /* !defined(__MINGW32__) && !defined(__CYGWIN32__) */
 
-#ifdef CCXX_NO_DLL
+#ifdef CCXX_STATIC
 #define	__DLLRTL  
 #define	__EXPORT  
+#define	__EXPORT_TEMPLATE(x)
 #else
 #define	__DLLRTL  __declspec(dllexport)
 #define	__EXPORT  __declspec(dllimport)
+#define	__EXPORT_TEMPLATE(x)	template class __EXPORT x;
 #endif
 
 #if !defined(_MSC_VER) || _MSC_VER >= 1300
@@ -222,11 +217,6 @@ typedef DWORD size_t;
 #define	snprintf	_snprintf
 #define	vsnprintf	_vsnprintf
 
-#define CCXX_EXPORT(t) __EXPORT t
-#define CCXX_MEMBER(t) t
-#define CCXX_MEMBER_EXPORT(t) __EXPORT CCXX_MEMBER(t CCXX_EMPTY)
-#define CCXX_CLASS_EXPORT __EXPORT
-
 typedef __int8  int8;
 typedef __int16 int16;
 typedef __int32 int32;
